<?php

namespace Flat101\Megamenu\Controller\Adminhtml\Item;

use Magento\Framework\Controller\Result\JsonFactory;

class Edit extends \Magento\Backend\App\Action
{
    /**
     * @var \Flat101\Megamenu\Model\MenuItemsFactory
     */
    protected $modelMenuFactory;

    /**
     * @var JsonFactory
     */
    protected $resultJsonFactory;

    /**
     * @var \Flat101\Megamenu\Model\MenuStoresFactory
     */
    protected $menuStoresFactory;

    /**
     * @var \Magento\Framework\App\Cache\TypeList
     */
    protected $cacheType;

    /**
     * Edit constructor.
     * @param \Magento\Backend\App\Action\Context $context
     * @param JsonFactory $resultJsonFactory
     * @param \Flat101\Megamenu\Model\MenuItemsFactory $modelMenuFactory
     * @param \Flat101\Megamenu\Model\MenuStoresFactory $menuStoresFactory
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        JsonFactory $resultJsonFactory,
        \Flat101\Megamenu\Model\MenuItemsFactory $modelMenuFactory,
        \Flat101\Megamenu\Model\MenuStoresFactory $menuStoresFactory,
        \Magento\Framework\App\Cache\TypeList $cacheType
    ) {
        parent::__construct($context);
        $this->resultJsonFactory = $resultJsonFactory;
        $this->modelMenuFactory = $modelMenuFactory;
        $this->menuStoresFactory = $menuStoresFactory;
        $this->cacheType = $cacheType;
    }

    /**
     * @return $this|\Magento\Framework\App\ResponseInterface|\Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $params = $this->getRequest()->getParams();
        $menu = $this->modelMenuFactory->create();
        $storeMenu = $this->menuStoresFactory->create();
        $resultEcho = $this->resultJsonFactory->create();

        try {
            if ($params['type'] == 'load') {
                $id = explode('_', $params['node_id']);
                $menu = $menu->getCollection()
                    ->addFieldToSelect('*')
                    ->addFieldToFilter('menu_id', $id[1])
                    ->addFieldToFilter('store_id', $params['store_id'])
                    ->getLastItem();

                $result = [];

                if (!empty($menu->getId())) {
                    $result = $menu->getData();
                    $result['content'] = unserialize($menu->getContent());
                    $result['empty'] = false;
                    $result['mega_menu_id'] = $id[1];
                } else {
                    $result['empty'] = true;
                    $result['mega_menu_id'] = $id[1];
                }

                $resultMenus = $result;
            } elseif ($params['type'] == 'save') {

                if ($params['megamenu_menu_url_type'] == '') {
                    $params['custom_link'] = '';
                    $params['megamenu_category_link'] = '';
                }

                $categoryStoreId = $params['category_store_id'];
                if ($categoryStoreId) {
                    $storeMenuItem = $storeMenu->load($categoryStoreId);
                    if ($storeMenuItem->getId()) {
                        $storeMenuItem->setData('name', $params['root_tore_menu']);
                        $storeMenuItem->save();
                    }
                }

                $menu = $menu->getCollection()
                    ->addFieldToSelect('*')
                    ->addFieldToFilter('menu_id', $params['menu_id'])
                    ->addFieldToFilter('store_id', $params['store_id'])
                    ->getLastItem();

                unset($params['type']);
                unset($params['form_key']);
                $this->setMegaMenuData($menu, $params);

                $result = $menu->getData();
                $result['content'] = unserialize($menu->getContent());
                $resultMenus = $result;
                $this->cacheType->invalidate('full_page');
            }
        } catch (\Exception $e) {
            $id = explode('_', $params['node_id']);
            $result = [];
            $result['error'] = true;
            $result['message'] = $e->getMessage();
            $result['empty'] = true;
            $result['mega_menu_id'] = $id[1];
            $resultMenus = $result;
        }

        return $resultEcho->setData($resultMenus);
    }

    protected function setMegaMenuData($menu, $params)
    {
        if (empty($params['item_id'])) {
            $menu->setMenuId($params['menu_id'])
                ->setStatus($params['megamenu_enable'])
                ->setType($params['megamenu_type'])
                ->setLabel($params['megamenu_label_type'])
                ->setContent(serialize($params))
                ->setBlockTop($params['megamenu_static_block_top'])
                ->setBlockLeft($params['megamenu_static_block_left'])
                ->setBlockRight($params['megamenu_static_block_right'])
                ->setBlockBottom($params['megamenu_static_block_bottom'])
                ->setBlockContent($params['megamenu_content_block'])
                ->setUrlType($params['megamenu_menu_url_type'])
                ->setCustomLink($params['custom_link'])
                ->setCategoryId($params['megamenu_category_link'])
                ->setStoreId($params['store_id'])
                ->setCustomCss($params['custom_css'])
                ->setCategoryStoreId($params['category_store_id'])
                ->save();
        } else {
            $menu->load($params['item_id'])
                ->setMenuId($params['menu_id'])
                ->setStatus($params['megamenu_enable'])
                ->setType($params['megamenu_type'])
                ->setLabel($params['megamenu_label_type'])
                ->setContent(serialize($params))
                ->setBlockTop($params['megamenu_static_block_top'])
                ->setBlockLeft($params['megamenu_static_block_left'])
                ->setBlockRight($params['megamenu_static_block_right'])
                ->setBlockBottom($params['megamenu_static_block_bottom'])
                ->setBlockContent($params['megamenu_content_block'])
                ->setUrlType($params['megamenu_menu_url_type'])
                ->setCustomLink($params['custom_link'])
                ->setCategoryId($params['megamenu_category_link'])
                ->setStoreId($params['store_id'])
                ->setCustomCss($params['custom_css'])
                ->setCategoryStoreId($params['category_store_id'])
                ->save();
        }
    }
}
